==> switch-check-button-1.1.6.tgz: package/README.md <==
# switch-check-button

## Install 
```js
npm install switch-check-button --save
```

## Usage
```vue
<template>
    <SwitchButton v-model="checked1" ></SwitchButton>
    <SwitchButton :value="checked2" @input="inpChangeHandler"></SwitchButton>
</template>

import SwitchButton from 'switch-check-button'

export default {
  // ...
  components: { SwitchButton },
  data() {
    return {
      checked1: false,
      checked2: false
    }
  },
  methods: {
    inpChangeHandler() {
      this.checked2 = !this.checked2
    }
  }
  // ...
}

```

The default Style
![default style](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAANgAAABYCAYAAACXkDk1AAAMO2lDQ1BJQ0MgUHJvZmlsZQAASImVVwdYU8kWnluSkJDQAhGQEnoTRKQjJYQWQUA62AhJgFBiCAQVO7Ko4NrFAjZ0RUTBtQCyFkTsLIK9L4ooKOtiwV7epICu+8r35vvmzn//OfOfM+fOvXcGAPVmrlichWoAkC3Kk0QF+zMTEpOYpF6AABSQAQFoc3m5YlZkZBiAZaj9e3lzHVrDcsVepvXP/v9aNPmCXB4ASCTEKfxcXjbEhwDAK3hiSR4ARBlvNiNPLMOwAm0JDBDiJTKcpsAVMpyiwPvlNjFRbIhbAVChcrmSNADUOiDPzOelQQ21AYgdRXyhCAB1JsQ+2dnT+RAnQ2wNbcQQy/TdU77TSfubZsqwJpebNowVc5EXlQBhrjiLO+v/TMf/LtlZ0iEflrBS0yUhUbI5w7zdzJweKsNUiPtFKeEREGtB/E7Il9tDjFLSpSGxCnvUgJfLhjkDDIgd+dyAUIgNIA4SZYWHKfmUVGEQB2K4QtCZwjxODMS6EC8R5AZGK222SaZHKX2h9akSNkvJn+NK5H5lvu5LM2NZSv2X6QKOUh9TK0iPiYeYArF5vjAuHGI1iB1yM6NDlTbjCtLZ4UM2EmmULH5ziKMEomB/hT6WnyoJilLal2TnDs0X25Yu5IQr8YG89JgQRX6wVh5XHj+cC9YhELFih3QEuQlhQ3PhCwICFXPHegWi2Gilzjtxnn+UYixOEWdFKu1xU0FWsIw3hdg5Nz9aORaPy4MLUqGPp4rzImMUceIFGdzxkYp48JUgDLBBAGACKawpYDrIAML2/oZ+eKfoCQJcIAFpQADslczQiHh5jwheo0EB+BMiAcgdHucv7xWAfMh/HmYVV3uQKu/Nl4/IBI8hzgahIAveS+WjRMPe4sAjyAj/4Z0LKw/GmwWrrP/f80PsN4YFmTAlIx3yyFQfsiQGEgOIIcQgog2uj/vgXngYvPrB6oS74x5D8/hmT3hM6CQ8JFwjdBFuTRMWSn6IcgLogvpBylykfJ8L3BJquuD+uDdUh8o4A9cH9rgz9MPCfaFnF8iylXHLssL8QftvM/juaSjtyI5klDyC7Ee2/nGkmq2ay7CKLNff50cRa8pwvtnDPT/6Z3+XfT5sQ3+0xJZgB7Gz2EnsPHYUawBM7ATWiLVhx2R4eHU9kq+uIW9R8ngyoY7wH/6Gnqwsk7mONY59jp8UfXmCmbJvNGBPF8+SCNPS85gs+EcQMDkinsMoppOjkzMAsv+L4vP1iiH/byCMC9+4nGYAPEogmfaN45oBcOQxAPQ33zizl/C1WQnAsQ6eVJKv4HDZhQC/EurwTdMDRsAMWMP5OAFX4AX8QCAYDyJADEgEU2H06XCdS8AMMAcsBMWgFKwE68AmsBXsALvBPnAANICj4CQ4Ay6CDnAN3IGrpwc8AwPgDfiIIAgJoSF0RA8xRiwQO8QJcUd8kEAkDIlCEpFkJA0RIVJkDrIIKUVWI5uQ7Ug18ityBDmJnEc6kVvIA6QPeYl8QDGUimqjhqglOhp1R1loKBqDTkHT0By0AC1Cl6Mb0Ep0L1qPnkQvotfQLvQZOogBTBVjYCaYPeaOsbEILAlLxSTYPKwEK8MqsVqsCT7nK1gX1o+9x4k4HWfi9nAFh+CxOA/Pwefhy/BN+G68Hm/Fr+AP8AH8C4FGMCDYETwJHEICIY0wg1BMKCPsIhwmnIbvUg/hDZFIZBCtiG7wXUwkZhBnE5cRNxPriM3ETmI3cZBEIumR7EjepAgSl5RHKiZtJO0lnSBdJvWQ3qmoqhirOKkEqSSpiFQKVcpU9qgcV7ms8kTlI1mDbEH2JEeQ+eRZ5BXkneQm8iVyD/kjRZNiRfGmxFAyKAspGyi1lNOUu5RXqqqqpqoeqhNVhaoLVDeo7lc9p/pA9T1Vi2pLZVMnU6XU5dQqajP1FvUVjUazpPnRkmh5tOW0atop2n3aOzW6moMaR42vNl+tXK1e7bLac3WyuoU6S32qeoF6mfpB9Uvq/RpkDUsNtgZXY55GucYRjRsag5p0zTGaEZrZmss092ie1+zVImlZagVq8bWKtHZondLqpmN0MzqbzqMvou+kn6b3aBO1rbQ52hnapdr7tNu1B3S0dJx14nRm6pTrHNPpYmAMSwaHkcVYwTjAuM74MMJwBGuEYMTSEbUjLo94qztS109XoFuiW6d7TfeDHlMvUC9Tb5Veg949fVzfVn+i/gz9Lfqn9ftHao/0GskbWTLywMjbBqiBrUGUwWyDHQZtBoOGRobBhmLDjYanDPuNGEZ+RhlGa42OG/UZ0419jIXGa41PGD9l6jBZzCzmBmYrc8DEwCTERGqy3aTd5KOplWmsaaFpnek9M4qZu1mq2VqzFrMBc2PzCeZzzGvMb1uQLdwt0i3WW5y1eGtpZRlvudiywbLXSteKY1VgVWN115pm7WudY11pfdWGaONuk2mz2abDFrV1sU23Lbe9ZIfaudoJ7TbbdY4ijPIYJRpVOeqGPdWeZZ9vX2P/wIHhEOZQ6NDg8Hy0+eik0atGnx39xdHFMctxp+OdMVpjxo8pHNM05qWTrRPPqdzp6lja2KCx88c2jn3hbOcscN7ifNOF7jLBZbFLi8tnVzdXiWuta5+buVuyW4XbDXdt90j3Ze7nPAge/h7zPY56vPd09czzPOD5l5e9V6bXHq/ecVbjBON2juv2NvXmem/37vJh+iT7bPPp8jXx5fpW+j70M/Pj++3ye8KyYWWw9rKe+zv6S/wP+79le7LnspsDsIDggJKA9kCtwNjATYH3g0yD0oJqggaCXYJnBzeHEEJCQ1aF3OAYcnicas7AeLfxc8e3hlJDo0M3hT4Msw2ThDVNQCeMn7Bmwt1wi3BReEMEiOBErIm4F2kVmRP520TixMiJ5RMfR42JmhN1NpoePS16T/SbGP+YFTF3Yq1jpbEtcepxk+Oq497GB8Svju9KGJ0wN+Fion6iMLExiZQUl7QraXBS4KR1k3omu0wunnx9itWUmVPOT9WfmjX12DT1adxpB5MJyfHJe5I/cSO4ldzBFE5KRcoAj81bz3vG9+Ov5fcJvAWrBU9SvVNXp/ameaetSetL900vS+8XsoWbhC8yQjK2ZrzNjMisyvyaFZ9Vl62SnZx9RKQlyhS1TjeaPnN6p9hOXCzuyvHMWZczIAmV7MpFcqfkNuZpw418m9Ra+pP0Qb5Pfnn+uxlxMw7O1Jwpmtk2y3bW0llPCoIKfpmNz+bNbpljMmfhnAdzWXO3z0PmpcxrmW82v2h+z4LgBbsXUhZmLvy90LFwdeHrRfGLmooMixYUdf8U/FNNsVqxpPjGYq/FW5fgS4RL2peOXbpx6ZcSfsmFUsfSstJPy3jLLvw85ucNP39dnrq8fYXrii0riStFK6+v8l21e7Xm6oLV3WsmrKlfy1xbsvb1umnrzpc5l21dT1kvXd+1IWxD40bzjSs3ftqUvulauX95XYVBxdKKt5v5my9v8dtSu9Vwa+nWD9uE225uD95eX2lZWbaDuCN/x+OdcTvP/uL+S/Uu/V2luz5Xiaq6dkftbq12q67eY7BnRQ1aI63p2zt5b8e+gH2Ntfa12+sYdaX7wX7p/qe/Jv96/UDogZaD7gdrD1kcqjhMP1xSj9TPqh9oSG/oakxs7Dwy/khLk1fT4d8cfqs6anK0/JjOsRXHKceLjn89UXBisFnc3H8y7WR3y7SWO6cSTl1tndjafjr09LkzQWdOnWWdPXHO+9zR857nj1xwv9Bw0fVifZtL2+HfXX4/3O7aXn/J7VJjh0dHU+e4zuOXfS+fvBJw5cxVztWL18KvdV6PvX7zxuQbXTf5N3tvZd16cTv/9sc7C+4S7pbc07hXdt/gfuUfNn/Udbl2HXsQ8KDtYfTDO9287mePch996il6THtc9sT4SXWvU+/RvqC+jqeTnvY8Ez/72F/8p+afFc+tnx/6y++vtoGEgZ4XkhdfXy57pfeq6rXz65bByMH7b7LffHxb8k7v3e737u/Pfoj/8OTjjE+kTxs+23xu+hL65e7X7K9fxVwJV74VwGBFU1MBeFkFAC0R7h3g+YwySXH+kxdEcWaVI/CfsOKMKC+uAFT5ARC7AIAwuEfZAqsFxFTYyrbwMX4AHTt2uA6d1eTnSlkhwnPANhsZam+jgB+L4sz5Xdw/tkCm6gx+bP8F3iR5bw24kSIAAABsZVhJZk1NACoAAAAIAAQBGgAFAAAAAQAAAD4BGwAFAAAAAQAAAEYBKAADAAAAAQACAACHaQAEAAAAAQAAAE4AAAAAAAAAkAAAAAEAAACQAAAAAQACoAIABAAAAAEAAADYoAMABAAAAAEAAABYAAAAADcmav4AAAAJcEhZcwAAFiUAABYlAUlSJPAAAA3sSURBVHgB7Z1bbxxJFcdP91ztsWMH49g4KJu1BYjdIGVRuD7ACrRcVvu4aB94AQmJD4AEX4QXnnjigWdWArESQjwgLYoACfaBXW3IBkXrZLGJ75475181x660Zzy3rpqeyWmrU9Uz3dXd/+pfzqlTNdVRs9lsx3FMuqgCqkD6CsRRFFG73U6/ZC1RFVAFKAZcgEwXVUAVSF+BiAFT85W+rlqiKmAUMI2vVqulcqgCqoAHBdRF9CCqFqkKiAJ5bX+JFJqqAukrYCxY+sVqiaqAKgAFFDB9DlQBjwqYfjCP5WvRqsAzrYABTKOIz/QzoDfvUQHtB/MorhatCph+MO1r1gdBFfCjgAFMQ/V+xNVSVQGNIuozoAp4VEAB8yiuFq0KaJhenwFVwKMCCphHcbVoVSDWPjB9CFQBfwpoP9iY2ia7ODQiO6agM3Z4HveDh0QfjMtrNgmSu7d8Bw0l736PvOqbVOTZ2I4ajUY7l8s9G3c7wl26wPTKdyvWBapXvttx+tlsKaAuYo/6FJjctFfeLUJgQtorj/3lO/dYzc+eAsZFnL3bGv2OkhBhu9/qnk3A6pfKMQqaKDGbqQLWqddeYCHKiu+QYuV5JM+2BTz30RCwMNck8nC/kZdtSWU/OVZBEyVmK1XAuD6TcAlMknI79QwuAIbPBTo5Vh4LgCIQIQVgAlk+nz+DDd9hxYJjUI5CJirOThrxw9LOcsX+fe8evXv0kB5Xn9BB/ZiqrTrVW/yQ8x87b/xnl/Pc8JUTdQqJ2mxxeMV2rsWgcD7fiqnQzlGZcjQflWjrygY9v7RBq5WrVCgUSKDBWQEeYKzX61StVqlWq5k8AMN+WCUv0AloUgeSDn8XekQWFYiyOHX2g5PH9Kedf9IHR4/ouFmlKvFD227wv+yitS1aQAwLMLOLpJ3NARIz3SqA4n1jPhxAxQwUICs0Y4YromIrR2vFZfrC2mfp1uoWLZbmByj5fBcAd3h4SEdHR8ZCCWiAE5DJCrDc9bwEzU2zApmKIn5U26M3t9+me0fbdNKumbXGYNUYrQaDVSfGil0pwGWtl4VqFOsFqGCxLFzWcsFaYQVURQZsJb9Ir37yy/SVjVup1PHe3h4dHBwYqACYWECxgrBmClkqUmemEANYFvz/3z2+S2/v/ov2W8d01K7Sabtu1qqxXE0GrGnAAloGL0T3WMbx4LJgGYvVAavUzFGJAfvmtZfo9c2XqZwvplpZcCN3dnaMC1ksFgmrgCbuots2S/XkWlhwBfKocKnQ4GfvnPCXD35P7x4+pP32iYHruANYjaGC1eoGFw61Vmy4q3YtV67NFovXItxC9jgjtlq5JtEPtr5NX79+e7iCB9wbWq+urhKs2f7+/lmABYfDksGCyX94kg5YtO6WQQUmPvHoz//9G/qA21x7bLkO26dn1guuoYGL7ZVtd9nWlkA1iuWC/nAKEbsDXAhmsOdJEVzDpm13/eSF79Htj3/Ke1UtLS0ZoHZ3d7ueCyACNl2mW4H8JP+XBFz3Tx7RE4YL1guW65jbXgaujkvoxgvZK+RF2l3DC39uvTjX4rA4F2UCGWy5yuwa/vSFN4LAJVdeqVRMFpC5bS/Jy34KmigxfamxYJOADG4hLJeF65gOWlUT1Kiy3aq77S02MUBKLJbFyxX64ifut24eUUJjE/gQpHm2XnAP0e768dZr9FIAy+VeD/KADJFGBD9gtWQFVGrFkmpN37axYKjIkAsCGu+hzcWW64AtF+CC9UI4HtbLWC0TxLABDXttF0G6+En3uzBQdb5C5DBG24vBKrTzDFeevrt2h75x/fPdDw7wKdxF6TNzAQNk+M8Pi1qxABXh4RRcn2HhQij+L4gWcnvrkKFCxBAheRcuaXOJ7RL7hUfNXYfRw4bk0f7izmMGrMArooXr+WX6/tYrwxTlZd+VlRUzDAvWDCuCT4BLAPNyUi3UuwKGLlRmqAX9XPstRAttQOOEw/Ho5xLLJR3J1iWUf0e/OrFeSE1HMlswE5bn0Rno73rjxss0ly+NfoKUjsR/dIuLiwYuGY7lQqagpSR04GLMrFKh3A+M0EAnMqzWUacjucqAYZSGdQvtKA3XYqWhB1pe9g/RQ44WsvUCXDdLqxN1DZP3BlcRIIkVUwuWVGj6ts2kN6EAw/AnGaFx6kQLMQQKIzTEJRy0bTWw3FygWDAe297p+8rRK+t3Bi4i1I4S9ID1ci0Yzq9WLFQtpHeeoPMiYmwhAMMoDelEfioMn959mZJc99AENxgzWDBpg3117cWUzzh+cQsLC6YtJm6iWDGFa3xtJ1FCMMAwKh4Dd9HWwvCns05kY72edg3TFKITmDcWDHkB7HOLN+lqaTHNU6VSFkZzYOgUAMOqYKUi68QKCTYvIn5yYiKFGLgrw586I+NTdwkTckoLzAY5MFo+pheXbyb2ys4mxie67qFClp26GfZKDGCoTN8Lfs+FMYUYFY8VriFihPIngY3Ur6NDr2mDsQVDmB6gbS5+IvVTpVVgqVQylkshS0vRyZVjwvQh+sIO6ydsuSxYcAiBl0HMt/libU1bDIEOXvG7L7iJ6/Mrk1O9z5nhIrpw9dldv86wAgawEC4IfolswbJw2R4uq0wAxhiy8z9YseXiQmarBe0w1Im7ysWGqCs5l6bjK2AACxGmb3XaWzzG1riFuHQLmV+8JJIoUsl22r/zkvLTSHt5FApXGuqGLSNYFDHsbenZVIFsKBAMsDjikeLsmsVsQuCsYbGp2BQ/giTto2yfNmp+TphCqb2CTiE8jRQuX4twFAgWpi/FBQZM/mx7SK7DL2L2LBKtRIrgypPaoZw+cymGSgEmd5WLVMhEielIgwG2UJgjnhWQJz87hwwWLcSPdo3VYoo5eEg8URQ1OZy4fbyT2RrCtG9ohwlgmb1QvbC+CgR7P9i10jLlI54fkF1FrADN2jGxZkg9LJ1CAZl0DbQYsHsHH3o4WTpFYk5FwOVCppYrHW1Dl8J1aAKJ3s/76cp1KrENK/LK028a2HKddpkXsJw7EvcQYLUi7ovj9Z0n9509spXFjy8VrmzVyahXE6wf7PbSJs3nSlSM+FfEvPK0m+cuYwc0CXuMejPdjrNdAegSsN0CcA8bDNg/Du7T/6oH3Q6Z6Gdof8FFdCcknegF6cnHUiDGgNJQ7sdzlTWai4pUjgoMWs5AZttk4iyOdS8XDpaIoYEL1osxE8DqDNmfH71z4ZhJf4BZgAUutWKTro3xzx+jMkMtX1u5ZQCzkPGkm7BkaJch8IE2h2mFeWiLsQ9q2mAMGcZAwoLV4ia9tX031K0PfB5Msd1tpl8UEOo/woEvVnfsq0CYBljnMm7MXaPNyjpV+CUKFbZkAK3E1qzAoBlLlnAV02qbSRsMkMGCwXoBsPvVj+gPD//aV6RQO2AyUkAEwLAir1CFUt/PeYIChlt4bf1LdCWeY8DKBrQ5uItsw2DNANl54AN4WWs2Dmium2iDHNZNrEdNA9mvH/yRThpVP+oOUSo6lzF1G8CCVwH3UF3EIQTM6K7BAVstLtEXP/YZusKALRhLVrKW7AJk6C+zkLmgnX8ynKJttlz4QzsMLiKsWJWt2HbjCf3q/beGK8zD3pivHmCJ9XLh8nA6LTKQAhOZ2fc71+7Qh6e7VD/8DzV59G8bvyHBFNbcE8xekZ14lAEADBEPEoYVci2RaGMtm3wjn16eAjSU3OAxW5hsp5qL6LeP7tLmwsbEJsCBa4i+r3K5bH7NLBZMXER1Ey+v0yx/G2wsYlKEH974Fj3HbbLleJ6t2TwtxmzRYmvNTJSRLZoJ5XMQBG6jdR3RQc0/++cV1s2uMjKkf2ofVMaSKQaWDbbftZgtGb/x4Rfvv0l/++97ycv0vo2gBl4CIW9ZEbjEgnm/AD2BVwUm/n6wibz8gemSN6sUeIbfcitPczzD73yzQD8LOD894MK89IALv2KW1xgJZGLBvD4BWrhXBTLxfrAsvL4I8yQCMqw/2nrV2+uLpDbl9UWXwYV91T0UxaYzzcwrZPUFfE+/IF3hmk6gkledqZeg6ytkuVXZ6ftSy5V8VKdzOzMWzJVPX4Ju46OuJpqfTgWMBcOlZ/V/TExYijkVMe3bQf2YMHlOveXOB2yFRx/XqAtH7s2CbgLMOIXtHP9wDNO72dcc5ajMsct57rfburJBzy9t0Grl6llQAhE/LOgslsG6CLvLK4nc/i3JSyADx7oRw6zWg7lB/WdoBTJpwYa+izEPkMlkZBYngOKugAbbMtsu8thXUvf0AESAQQqQBCZ0IgtQkmJ/gUpStzzNT7cCEw/TZ0W+JGQubAKTQCbbso97DwKMQCZwybaksp9AJalbluanXwEDGB4cVLwuPGKELRMWgWeQ1NXNBadfHscpWK56s5efyFCpLMvoPvDIJ4HDtQt0knfvR45H2iuP/eU791jNz54C6iL2qVMBDLv1yncrwgWoV77bcfrZbCmQqX6wLEvrwpW8TvnOBSm5z2XfJffV7dlRQF3EAeuyFyCAy/3OzQ9YtO42wwrk9YEYr3ZVv/H0m/Wjg70fbNaF1PtTBbopoEGObqroZ6pASgqYzi9ppKdUphajCqgCHQUMYNqO0OdBFfCjwMSmDPBzO1qqKpAtBRSwbNWHXs2MKRDs9UUzppvejiowkAIK2EAy6U6qwGgKBHs/2GiXp0epAtOtgPaDTXf96dVnXAHtB8t4BenlTbcCQd8PNt1S6dWrAsMroC7i8JrpEarAwAroPAEDS6U7qgLDK/B/3OO141KQU6AAAAAASUVORK5CYII=)

## API 
| key      | value   | information |
| -------- | ------- | ----------- |
| value    | Boolean or String or Number | Default value is false. When Boolean(value) is true, checked.  |
| name     | String  | Default is value null. |
| label    | String | Default value is null. If it is not empty, it will show the label. |
| classes  | String  | Default value is null. Customer className.  |
| disabled | Boolean | Default value is false. When disabled value is true, it could not be clicked. |
| checkedText | Array | Default value is ['close', 'open'], index=0 is false text, index=1 is true text. When showText prop is true, it will be shown. |
| showText | Boolean | Default value is false. When it is true, the text will be shown. |
| checkedColors | Array | Default ['red', 'green']|

==> switch-check-button-1.1.9.tgz: package/README.md <==
# switch-check-button

## Install 
```js
npm install switch-check-button --save
```

## Usage
```vue
<template>
  <div>
    <!-- The Props All -->
    <SwitchButton v-model="checked1" label="Open the Switch" classes="my-class-name"
      :disabled="false" 
      :showText="true"
      :checkedText="['No', 'Yes']"
      :checkedColors="['gray', 'blue']"></SwitchButton>

    <!-- v-modal && change Event -->
    <SwitchButton v-model="checked1" @change="changeHandler"></SwitchButton>

    <!-- value && input Event -->
    <SwitchButton :value="checked2" @input="inpChangeHandler"></SwitchButton>
  </div>
</template>

import SwitchButton from 'switch-check-button'

export default {
  // ...
  components: { SwitchButton },
  data() {
    return {
      checked1: false,
      checked2: false
    }
  },
  methods: {
    changeHandler(val) {
      console.log(val)
    },
    inpChangeHandler() {
      this.checked2 = !this.checked2
    }
  }
  // ...
}

```

## API 
| key      | value   | information |
| -------- | ------- | ----------- |
| value    | Boolean or String or Number | Default value is false. When Boolean(value) is true, checked.  |
| name     | String  | Default value is null. |
| label    | String | Default value is null. If it is not empty, it will show the label. |
| classes  | String  | Default value is null. Customer className.  |
| disabled | Boolean | Default value is false. When disabled value is true, it could not be clicked. |
| checkedText | Array | Default value is ['close', 'open'], index=0 is false text, index=1 is true text. When showText prop is true, it will be shown. |
| showText | Boolean | Default value is false. When it is true, the text will be shown. |
| checkedColors | Array | Default ['red', 'green']|
| @change | Function | Function that could get the checked status. |


![alt text](image-1.png)
